@@ -5,12 +5,8 @@ sub get_person {
     my ($self, $person_r, $mail, $role, $name, $address) = @_;
     return if $$person_r;
     my %seen;
-    my @candidates = 
-        grep {! $seen{$_->id}++ }
-        map { $_->entity }
-    Email::Store::Addressing->search(
-            name => $name->id,
-            address => $address->id
+    my @candidates = Email::Store::Entity->search_distinct_entity(
+        $name->id, $address->id
     );
     if (@candidates == 0) {
        $$person_r = Email::Store::Entity->create({notes => ""});
